@@ -92,6 +92,8 @@ impl Class {
     pub fn gen(&self, gen: &Gen, include: TypeInclude) -> TokenStream {
         let name = gen_type_name(&self.0, gen);
         let interfaces = self.interfaces();
+        let features = gen.class_features(&self.0);
+        let cfg = gen.gen_cfg(&features);
 
         if include == TypeInclude::Full {
             let methods = InterfaceInfo::gen_methods(&interfaces, gen);
@@ -105,11 +107,11 @@ impl Class {
                             let interface_type = gen_type_name(&interface.def, gen);
 
                             Some(quote! {
-                                pub fn #interface_name<R, F: FnOnce(&#interface_type) -> ::windows::Result<R>>(
+                                pub fn #interface_name<R, F: FnOnce(&#interface_type) -> ::windows::runtime::Result<R>>(
                                     callback: F,
-                                ) -> ::windows::Result<R> {
-                                    static mut SHARED: ::windows::FactoryCache<#name, #interface_type> =
-                                        ::windows::FactoryCache::new();
+                                ) -> ::windows::runtime::Result<R> {
+                                    static mut SHARED: ::windows::runtime::FactoryCache<#name, #interface_type> =
+                                        ::windows::runtime::FactoryCache::new();
                                     unsafe { SHARED.call(callback) }
                                 }
                             })
@@ -127,19 +129,19 @@ impl Class {
                 let guid = gen_type_guid(&default_interface.def, gen);
                 let default_abi_name = gen_abi_name(&default_interface.def, gen);
                 let type_signature = Literal::byte_string(self.0.type_signature().as_bytes());
-                let object = gen_object(&name, &TokenStream::new());
+                let object = gen_object(&name, &TokenStream::new(), &cfg);
                 let (async_get, future) = gen_async(&self.0, &interfaces, gen);
 
                 let new = if self.0.has_default_constructor() {
                     quote! {
-                        pub fn new() -> ::windows::Result<Self> {
+                        pub fn new() -> ::windows::runtime::Result<Self> {
                             Self::IActivationFactory(|f| f.activate_instance::<Self>())
                         }
-                        fn IActivationFactory<R, F: FnOnce(&::windows::IActivationFactory) -> ::windows::Result<R>>(
+                        fn IActivationFactory<R, F: FnOnce(&::windows::runtime::IActivationFactory) -> ::windows::runtime::Result<R>>(
                             callback: F,
-                        ) -> ::windows::Result<R> {
-                            static mut SHARED: ::windows::FactoryCache<#name, ::windows::IActivationFactory> =
-                                ::windows::FactoryCache::new();
+                        ) -> ::windows::runtime::Result<R> {
+                            static mut SHARED: ::windows::runtime::FactoryCache<#name, ::windows::runtime::IActivationFactory> =
+                                ::windows::runtime::FactoryCache::new();
                             unsafe { SHARED.call(callback) }
                         }
                     }
@@ -147,13 +149,15 @@ impl Class {
                     quote! {}
                 };
 
-                let conversions = interfaces
-                    .iter()
-                    .map(|interface| interface.gen_conversion(&name, &TokenStream::new(), gen));
+                let conversions = interfaces.iter().map(|interface| {
+                    interface.gen_conversion(&name, &TokenStream::new(), &features, gen)
+                });
 
                 let send_sync = if self.0.is_agile() {
                     quote! {
+                        #cfg
                         unsafe impl ::std::marker::Send for #name {}
+                        #cfg
                         unsafe impl ::std::marker::Sync for #name {}
                     }
                 } else {
@@ -164,23 +168,28 @@ impl Class {
                 let iterator = gen_iterator(&self.0, &interfaces, gen);
 
                 quote! {
+                    #cfg
                     #[repr(transparent)]
                     #[derive(::std::cmp::PartialEq, ::std::cmp::Eq, ::std::clone::Clone, ::std::fmt::Debug)]
-                    pub struct #name(::windows::IInspectable);
+                    pub struct #name(::windows::runtime::IInspectable);
+                    #cfg
                     impl #name {
                         #new
                         #methods
                         #async_get
                         #(#factories)*
                     }
-                    unsafe impl ::windows::RuntimeType for #name {
-                        const SIGNATURE: ::windows::ConstBuffer = ::windows::ConstBuffer::from_slice(#type_signature);
+                    #cfg
+                    unsafe impl ::windows::runtime::RuntimeType for #name {
+                        const SIGNATURE: ::windows::runtime::ConstBuffer = ::windows::runtime::ConstBuffer::from_slice(#type_signature);
                     }
-                    unsafe impl ::windows::Interface for #name {
+                    #cfg
+                    unsafe impl ::windows::runtime::Interface for #name {
                         type Vtable = #default_abi_name;
-                        const IID: ::windows::Guid = #guid;
+                        const IID: ::windows::runtime::GUID = #guid;
                     }
-                    impl ::windows::RuntimeName for #name {
+                    #cfg
+                    impl ::windows::runtime::RuntimeName for #name {
                         const NAME: &'static str = #runtime_name;
                     }
                     #future
@@ -197,7 +206,7 @@ impl Class {
                         #methods
                         #(#factories)*
                     }
-                    impl ::windows::RuntimeName for #name {
+                    impl ::windows::runtime::RuntimeName for #name {
                         const NAME: &'static str = #runtime_name;
                     }
                 }
@@ -212,16 +221,19 @@ impl Class {
             let type_signature = Literal::byte_string(self.0.type_signature().as_bytes());
 
             quote! {
+                #cfg
                 #[repr(transparent)]
                 #[derive(::std::cmp::PartialEq, ::std::cmp::Eq, ::std::clone::Clone, ::std::fmt::Debug)]
                 #[doc(hidden)]
-                pub struct #name(::windows::IInspectable);
-                unsafe impl ::windows::Interface for #name {
-                    type Vtable = <::windows::IUnknown as ::windows::Interface>::Vtable;
-                    const IID: ::windows::Guid = #guid;
+                pub struct #name(::windows::runtime::IInspectable);
+                #cfg
+                unsafe impl ::windows::runtime::Interface for #name {
+                    type Vtable = <::windows::runtime::IUnknown as ::windows::runtime::Interface>::Vtable;
+                    const IID: ::windows::runtime::GUID = #guid;
                 }
-                unsafe impl ::windows::RuntimeType for #name {
-                    const SIGNATURE: ::windows::ConstBuffer = ::windows::ConstBuffer::from_slice(#type_signature);
+                #cfg
+                unsafe impl ::windows::runtime::RuntimeType for #name {
+                    const SIGNATURE: ::windows::runtime::ConstBuffer = ::windows::runtime::ConstBuffer::from_slice(#type_signature);
                 }
             }
         }
@@ -235,27 +247,43 @@ impl Class {
         self.0.bases().map(move |base| {
             let into = gen_type_name(&base, gen);
 
+            let mut features = BTreeSet::new();
+
+            if let Some(def) = self.0.default_interface() {
+                features.insert(def.namespace());
+            }
+
+            if let Some(def) = base.default_interface() {
+                features.insert(def.namespace());
+            }
+
+            let cfg = gen.gen_cfg(&features);
+
             quote! {
+                #cfg
                 impl ::std::convert::From<#from> for #into {
                     fn from(value: #from) -> Self {
                         ::std::convert::Into::<#into>::into(&value)
                     }
                 }
+                #cfg
                 impl ::std::convert::From<&#from> for #into {
                     fn from(value: &#from) -> Self {
                         // This unwrap is legitimate because conversion to base can never fail because 
                         // the base can never change across versions.
-                        ::windows::Interface::cast(value).unwrap()
+                        ::windows::runtime::Interface::cast(value).unwrap()
                     }
                 }
-                impl<'a> ::windows::IntoParam<'a, #into> for #from {
-                    fn into_param(self) -> ::windows::Param<'a, #into> {
-                        ::windows::Param::Owned(::std::convert::Into::<#into>::into(self))
+                #cfg
+                impl<'a> ::windows::runtime::IntoParam<'a, #into> for #from {
+                    fn into_param(self) -> ::windows::runtime::Param<'a, #into> {
+                        ::windows::runtime::Param::Owned(::std::convert::Into::<#into>::into(self))
                     }
                 }
-                impl<'a> ::windows::IntoParam<'a, #into> for &#from {
-                    fn into_param(self) -> ::windows::Param<'a, #into> {
-                        ::windows::Param::Owned(::std::convert::Into::<#into>::into(::std::clone::Clone::clone(self)))
+                #cfg
+                impl<'a> ::windows::runtime::IntoParam<'a, #into> for &#from {
+                    fn into_param(self) -> ::windows::runtime::Param<'a, #into> {
+                        ::windows::runtime::Param::Owned(::std::convert::Into::<#into>::into(::std::clone::Clone::clone(self)))
                     }
                 }
             }
@@ -287,20 +315,20 @@ mod tests {
         assert_eq!(i.len(), 3);
 
         assert_eq!(
-            gen_type_name(&i[0].def, &Gen::Absolute).as_str(),
-            "Windows::Foundation::Collections:: IMap :: < :: windows :: HSTRING , :: windows :: HSTRING >"
+            gen_type_name(&i[0].def, &Gen::absolute()).as_str(),
+            "Windows::Foundation::Collections:: IMap :: < :: windows :: runtime :: HSTRING , :: windows :: runtime :: HSTRING >"
         );
         assert_eq!(i[0].kind, InterfaceKind::Default);
 
         assert_eq!(
-            gen_type_name(&i[1].def, &Gen::Absolute).as_str(),
-            "Windows::Foundation::Collections:: IIterable :: < Windows::Foundation::Collections:: IKeyValuePair :: < :: windows :: HSTRING , :: windows :: HSTRING > >"
+            gen_type_name(&i[1].def, &Gen::absolute()).as_str(),
+            "Windows::Foundation::Collections:: IIterable :: < Windows::Foundation::Collections:: IKeyValuePair :: < :: windows :: runtime :: HSTRING , :: windows :: runtime :: HSTRING > >"
         );
         assert_eq!(i[1].kind, InterfaceKind::NonDefault);
 
         assert_eq!(
-            gen_type_name(&i[2].def, &Gen::Absolute).as_str(),
-            "Windows::Foundation::Collections:: IObservableMap :: < :: windows :: HSTRING , :: windows :: HSTRING >"
+            gen_type_name(&i[2].def, &Gen::absolute()).as_str(),
+            "Windows::Foundation::Collections:: IObservableMap :: < :: windows :: runtime :: HSTRING , :: windows :: runtime :: HSTRING >"
         );
         assert_eq!(i[2].kind, InterfaceKind::NonDefault);
     }
