@@ -14,6 +14,8 @@ pub fn gen_delegate(def: &TypeDef, gen: &Gen) -> TokenStream {
     let vtable_phantoms = gen_phantoms(def);
     let constraints = gen_constraints(def);
 
+    let features = method_features(&signature, gen);
+
     let method = MethodInfo {
         name: "Invoke".to_string(),
         vtable_offset: 3,
@@ -55,14 +57,16 @@ pub fn gen_delegate(def: &TypeDef, gen: &Gen) -> TokenStream {
     let invoke_upcall = gen_winrt_upcall(&signature, quote! { ((*this).invoke) }, gen);
 
     quote! {
+        #features
         #[repr(transparent)]
         #[derive(::std::cmp::PartialEq, ::std::cmp::Eq, ::std::clone::Clone, ::std::fmt::Debug)]
-        pub struct #name(::windows::IUnknown, #(#struct_phantoms,)*) where #constraints;
+        pub struct #name(::windows::runtime::IUnknown, #(#struct_phantoms,)*) where #constraints;
+        #features
         impl<#constraints> #name {
             pub fn new<#fn_constraint>(invoke: F) -> Self {
                 let com = #box_name {
                     vtable: &#box_name::VTABLE,
-                    count: ::windows::RefCount::new(1),
+                    count: ::windows::runtime::RefCount::new(1),
                     invoke,
                 };
                 unsafe {
@@ -71,28 +75,33 @@ pub fn gen_delegate(def: &TypeDef, gen: &Gen) -> TokenStream {
             }
             #invoke
         }
-        unsafe impl<#constraints> ::windows::RuntimeType for #name {
-            const SIGNATURE: ::windows::ConstBuffer = #type_signature;
+        #features
+        unsafe impl<#constraints> ::windows::runtime::RuntimeType for #name {
+            const SIGNATURE: ::windows::runtime::ConstBuffer = #type_signature;
         }
-        unsafe impl<#constraints> ::windows::Interface for #name {
+        #features
+        unsafe impl<#constraints> ::windows::runtime::Interface for #name {
             type Vtable = #abi_name;
-            const IID: ::windows::Guid = #guid;
+            const IID: ::windows::runtime::GUID = #guid;
         }
+        #features
         #[repr(C)]
         #[doc(hidden)]
         pub struct #abi_name(
-            pub unsafe extern "system" fn(this: ::windows::RawPtr, iid: &::windows::Guid, interface: *mut ::windows::RawPtr) -> ::windows::HRESULT,
-            pub unsafe extern "system" fn(this: ::windows::RawPtr) -> u32,
-            pub unsafe extern "system" fn(this: ::windows::RawPtr) -> u32,
+            pub unsafe extern "system" fn(this: ::windows::runtime::RawPtr, iid: &::windows::runtime::GUID, interface: *mut ::windows::runtime::RawPtr) -> ::windows::runtime::HRESULT,
+            pub unsafe extern "system" fn(this: ::windows::runtime::RawPtr) -> u32,
+            pub unsafe extern "system" fn(this: ::windows::runtime::RawPtr) -> u32,
             pub unsafe extern "system" fn #abi_signature,
             #(pub #abi_phantoms,)*
         ) where #constraints;
+        #features
         #[repr(C)]
         struct #box_definition where #constraints {
             vtable: *const #abi_name,
             invoke: F,
-            count: ::windows::RefCount,
+            count: ::windows::runtime::RefCount,
         }
+        #features
         impl<#constraints #fn_constraint> #box_name {
             const VTABLE: #abi_name = #turbo_abi_name(
                 Self::QueryInterface,
@@ -101,12 +110,12 @@ pub fn gen_delegate(def: &TypeDef, gen: &Gen) -> TokenStream {
                 Self::Invoke,
                 #(#vtable_phantoms,)*
             );
-            unsafe extern "system" fn QueryInterface(this: ::windows::RawPtr, iid: &::windows::Guid, interface: *mut ::windows::RawPtr) -> ::windows::HRESULT {
-                let this = this as *mut ::windows::RawPtr as *mut Self;
+            unsafe extern "system" fn QueryInterface(this: ::windows::runtime::RawPtr, iid: &::windows::runtime::GUID, interface: *mut ::windows::runtime::RawPtr) -> ::windows::runtime::HRESULT {
+                let this = this as *mut ::windows::runtime::RawPtr as *mut Self;
 
-                *interface = if iid == &<#name as ::windows::Interface>::IID ||
-                    iid == &<::windows::IUnknown as ::windows::Interface>::IID ||
-                    iid == &<::windows::IAgileObject as ::windows::Interface>::IID {
+                *interface = if iid == &<#name as ::windows::runtime::Interface>::IID ||
+                    iid == &<::windows::runtime::IUnknown as ::windows::runtime::Interface>::IID ||
+                    iid == &<::windows::runtime::IAgileObject as ::windows::runtime::Interface>::IID {
                         &mut (*this).vtable as *mut _ as _
                     } else {
                         ::std::ptr::null_mut()
@@ -115,18 +124,18 @@ pub fn gen_delegate(def: &TypeDef, gen: &Gen) -> TokenStream {
                 // TODO: implement IMarshal
 
                 if (*interface).is_null() {
-                    ::windows::HRESULT(0x8000_4002) // E_NOINTERFACE
+                    ::windows::runtime::HRESULT(0x8000_4002) // E_NOINTERFACE
                 } else {
                     (*this).count.add_ref();
-                    ::windows::HRESULT(0)
+                    ::windows::runtime::HRESULT(0)
                 }
             }
-            unsafe extern "system" fn AddRef(this: ::windows::RawPtr) -> u32 {
-                let this = this as *mut ::windows::RawPtr as *mut Self;
+            unsafe extern "system" fn AddRef(this: ::windows::runtime::RawPtr) -> u32 {
+                let this = this as *mut ::windows::runtime::RawPtr as *mut Self;
                 (*this).count.add_ref()
             }
-            unsafe extern "system" fn Release(this: ::windows::RawPtr) -> u32 {
-                let this = this as *mut ::windows::RawPtr as *mut Self;
+            unsafe extern "system" fn Release(this: ::windows::runtime::RawPtr) -> u32 {
+                let this = this as *mut ::windows::runtime::RawPtr as *mut Self;
                 let remaining = (*this).count.release();
 
                 if remaining == 0 {
@@ -136,7 +145,7 @@ pub fn gen_delegate(def: &TypeDef, gen: &Gen) -> TokenStream {
                 remaining
             }
             unsafe extern "system" fn Invoke #abi_signature {
-                let this = this as *mut ::windows::RawPtr as *mut Self;
+                let this = this as *mut ::windows::runtime::RawPtr as *mut Self;
                 #invoke_upcall
             }
         }
@@ -150,7 +159,7 @@ fn gen_winrt_constraint(sig: &MethodSignature, gen: &Gen) -> TokenStream {
         let tokens = gen_name(&return_sig.kind, gen);
 
         if return_sig.is_array {
-            quote! { ::windows::Array<#tokens> }
+            quote! { ::windows::runtime::Array<#tokens> }
         } else {
             tokens
         }
@@ -158,5 +167,5 @@ fn gen_winrt_constraint(sig: &MethodSignature, gen: &Gen) -> TokenStream {
         quote! { () }
     };
 
-    quote! { F: FnMut(#(#params),*) -> ::windows::Result<#return_sig> + 'static }
+    quote! { F: FnMut(#(#params),*) -> ::windows::runtime::Result<#return_sig> + 'static }
 }
